==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="360"/>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="393"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="395"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="402"/>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="409"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="418"/>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="427"/>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="432"/>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="438"/>
        <source>&amp;Restore</source>
        <translation>&amp;Odzyskaj</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="442"/>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="448"/>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="454"/>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="463"/>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="465"/>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="470"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="475"/>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="483"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Razor - ustawienia listy zadań</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Zawartość listy zadań</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Wygląd listy zadań</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Maksymalna szerokość</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="41"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="42"/>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Odzyskaj</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Ustawienia listy zadań Razor</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Zawartość listy zadań</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Wygląd listy zadań</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Maksymalna szerokość</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Zamknij środkowym klawiszem</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
</context>
</TS>
